@@ -1,25 +1,13 @@
 /*
- *  Copyright 2012  Sebastian Gottfried <sebastiangottfried@web.de>
+ *  SPDX-FileCopyrightText: 2012 Sebastian Gottfried <sebastiangottfried@web.de>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "keyboardlayoutpropertieswidget.h"
 
-#include <QUndoStack>
 #include <QFontDatabase>
-#include <QStyledItemDelegate>
+#include <QUndoStack>
 
 #include "core/keyboardlayout.h"
 #include "core/abstractkey.h"
@@ -31,11 +19,11 @@
 
 KeyboardLayoutPropertiesWidget::KeyboardLayoutPropertiesWidget(QWidget* parent) :
     QWidget(parent),
-    m_keyboardLayout(0),
+    m_keyboardLayout(nullptr),
     m_selectedKeyIndex(-1),
-    m_selectedKey(0),
+    m_selectedKey(nullptr),
     m_readOnly(false),
-    m_undoStack(0),
+    m_undoStack(nullptr),
     m_charactersModel(new CharactersModel(this)),
     m_charactersViewDelegate(new CharactersViewDelegate(this))
 {
@@ -100,7 +88,7 @@ void KeyboardLayoutPropertiesWidget::setSelectedKey(int index)
 
     if (index == -1)
     {
-        m_selectedKey = 0;
+        m_selectedKey = nullptr;
 
         m_charactersModel->setKeyIndex(-1);
 
@@ -108,7 +96,7 @@ void KeyboardLayoutPropertiesWidget::setSelectedKey(int index)
     }
     else
     {
-        m_selectedKey = 0;
+        m_selectedKey = nullptr;
         resetKeyGeometry(m_keyboardLayout->key(index));
         m_selectedKey = m_keyboardLayout->key(index);
 
